==> openshift-model-whereabouts-6.5.1-sources.jar: io/fabric8/openshift/api/model/whereabouts/v1alpha1/IPPoolSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.whereabouts.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IPPoolSpecFluentImpl<A extends IPPoolSpecFluent<A>> extends BaseFluent<A> implements IPPoolSpecFluent<A>{
  public IPPoolSpecFluentImpl() {
  }
  public IPPoolSpecFluentImpl(IPPoolSpec instance) {
    this.withAllocations(instance.getAllocations()); 
    this.withRange(instance.getRange()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private Map<String,IPAllocation> allocations;
  private String range;
  private Map<String,Object> additionalProperties;
  public A addToAllocations(String key,IPAllocation value) {
    if(this.allocations == null && key != null && value != null) { this.allocations = new LinkedHashMap(); }
    if(key != null && value != null) {this.allocations.put(key, value);} return (A)this;
  }
  public A addToAllocations(Map<String,IPAllocation> map) {
    if(this.allocations == null && map != null) { this.allocations = new LinkedHashMap(); }
    if(map != null) { this.allocations.putAll(map);} return (A)this;
  }
  public A removeFromAllocations(String key) {
    if(this.allocations == null) { return (A) this; }
    if(key != null && this.allocations != null) {this.allocations.remove(key);} return (A)this;
  }
  public A removeFromAllocations(Map<String,IPAllocation> map) {
    if(this.allocations == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.allocations != null){this.allocations.remove(key);}}} return (A)this;
  }
  public Map<String,IPAllocation> getAllocations() {
    return this.allocations;
  }
  public <K,V>A withAllocations(Map<String,IPAllocation> allocations) {
    if (allocations == null) { this.allocations =  null;} else {this.allocations = new LinkedHashMap(allocations);} return (A) this;
  }
  public Boolean hasAllocations() {
    return this.allocations != null;
  }
  public String getRange() {
    return this.range;
  }
  public A withRange(String range) {
    this.range=range; return (A) this;
  }
  public Boolean hasRange() {
    return this.range != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IPPoolSpecFluentImpl that = (IPPoolSpecFluentImpl) o;
    if (allocations != null ? !allocations.equals(that.allocations) :that.allocations != null) return false;
    if (range != null ? !range.equals(that.range) :that.range != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allocations,  range,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (allocations != null && !allocations.isEmpty()) { sb.append("allocations:"); sb.append(allocations + ","); }
    if (range != null) { sb.append("range:"); sb.append(range + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-whereabouts-6.7.1-sources.jar: io/fabric8/openshift/api/model/whereabouts/v1alpha1/IPPoolSpecFluentImpl.java <==
package io.fabric8.openshift.api.model.whereabouts.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class IPPoolSpecFluentImpl<A extends IPPoolSpecFluent<A>> extends BaseFluent<A> implements IPPoolSpecFluent<A>{
  public IPPoolSpecFluentImpl() {
  }
  public IPPoolSpecFluentImpl(IPPoolSpec instance) {
    if (instance != null) {
      this.withAllocations(instance.getAllocations());
      this.withRange(instance.getRange());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Map<String,IPAllocation> allocations;
  private String range;
  private Map<String,Object> additionalProperties;
  public A addToAllocations(String key,IPAllocation value) {
    if(this.allocations == null && key != null && value != null) { this.allocations = new LinkedHashMap(); }
    if(key != null && value != null) {this.allocations.put(key, value);} return (A)this;
  }
  public A addToAllocations(Map<String,IPAllocation> map) {
    if(this.allocations == null && map != null) { this.allocations = new LinkedHashMap(); }
    if(map != null) { this.allocations.putAll(map);} return (A)this;
  }
  public A removeFromAllocations(String key) {
    if(this.allocations == null) { return (A) this; }
    if(key != null && this.allocations != null) {this.allocations.remove(key);} return (A)this;
  }
  public A removeFromAllocations(Map<String,IPAllocation> map) {
    if(this.allocations == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.allocations != null){this.allocations.remove(key);}}} return (A)this;
  }
  public Map<String,IPAllocation> getAllocations() {
    return this.allocations;
  }
  public <K,V>A withAllocations(Map<String,IPAllocation> allocations) {
    if (allocations == null) { this.allocations =  null;} else {this.allocations = new LinkedHashMap(allocations);} return (A) this;
  }
  public Boolean hasAllocations() {
    return this.allocations != null;
  }
  public String getRange() {
    return this.range;
  }
  public A withRange(String range) {
    this.range=range; return (A) this;
  }
  public Boolean hasRange() {
    return this.range != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    IPPoolSpecFluentImpl that = (IPPoolSpecFluentImpl) o;
    if (!java.util.Objects.equals(allocations, that.allocations)) return false;

    if (!java.util.Objects.equals(range, that.range)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(allocations,  range,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (allocations != null && !allocations.isEmpty()) { sb.append("allocations:"); sb.append(allocations + ","); }
    if (range != null) { sb.append("range:"); sb.append(range + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
